Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1476)

Unified Diff: content/shell/shell_browser_context.cc

Issue 9568002: Renamed speech input implementation from to speech_recognition_*. The namespace has been renamed fr… (Closed) Base URL: http://git.chromium.org/chromium/src.git@master
Patch Set: Rebased from master. Created 8 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/shell/shell_browser_context.h ('k') | content/shell/shell_content_browser_client.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/shell/shell_browser_context.cc
diff --git a/content/shell/shell_browser_context.cc b/content/shell/shell_browser_context.cc
index f617b23fd527759dace01d6f94a4501474d9c618..4872dc605e263a77bda139306959f50d8540b6d2 100644
--- a/content/shell/shell_browser_context.cc
+++ b/content/shell/shell_browser_context.cc
@@ -13,7 +13,7 @@
#include "content/browser/download/download_manager_impl.h"
#include "content/public/browser/browser_thread.h"
#include "content/public/browser/geolocation_permission_context.h"
-#include "content/public/browser/speech_input_preferences.h"
+#include "content/public/browser/speech_recognition_preferences.h"
#include "content/shell/shell_browser_main.h"
#include "content/shell/shell_download_manager_delegate.h"
#include "content/shell/shell_resource_context.h"
@@ -63,12 +63,12 @@ class ShellGeolocationPermissionContext : public GeolocationPermissionContext {
DISALLOW_COPY_AND_ASSIGN(ShellGeolocationPermissionContext);
};
-class ShellSpeechInputPreferences : public SpeechInputPreferences {
+class ShellSpeechRecognitionPreferences : public SpeechRecognitionPreferences {
public:
- ShellSpeechInputPreferences() {
+ ShellSpeechRecognitionPreferences() {
}
// Overridden from SpeechInputPreferences:
virtual bool FilterProfanities() const OVERRIDE {
return false;
}
@@ -77,7 +77,7 @@ class ShellSpeechInputPreferences : public SpeechInputPreferences {
}
private:
- DISALLOW_COPY_AND_ASSIGN(ShellSpeechInputPreferences);
+ DISALLOW_COPY_AND_ASSIGN(ShellSpeechRecognitionPreferences);
};
} // namespace
@@ -170,10 +170,11 @@ GeolocationPermissionContext*
return geolocation_permission_context_;
}
-SpeechInputPreferences* ShellBrowserContext::GetSpeechInputPreferences() {
- if (!speech_input_preferences_.get())
- speech_input_preferences_ = new ShellSpeechInputPreferences();
- return speech_input_preferences_.get();
+SpeechRecognitionPreferences*
+ ShellBrowserContext::GetSpeechRecognitionPreferences() {
+ if (!speech_recognition_preferences_.get())
+ speech_recognition_preferences_ = new ShellSpeechRecognitionPreferences();
+ return speech_recognition_preferences_.get();
}
bool ShellBrowserContext::DidLastSessionExitCleanly() {
« no previous file with comments | « content/shell/shell_browser_context.h ('k') | content/shell/shell_content_browser_client.h » ('j') | no next file with comments »
@@ -63,12 +63,12 @@ class ShellGeolocationPermissionContext : public GeolocationPermissionContext {
}
- // Overridden from SpeechInputPreferences:
+ // Overridden from SpeechRecognitionPreferences:
virtual bool FilterProfanities() const OVERRIDE {
return false;

Powered by Google App Engine
This is Rietveld 408576698